@@ -1,7 +1,7 @@
 /*
  * IPVS         Application module
  *
- * Version:     $Id: ip_vs_app.c,v 1.3 2000/07/06 14:57:09 wensong Exp $
+ * Version:     $Id: ip_vs_app.c,v 1.4 2000/09/06 08:36:36 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -16,7 +16,7 @@
  *
  *		IP_MASQ_APP application masquerading module
  *
- * 	$Id: ip_vs_app.c,v 1.3 2000/07/06 14:57:09 wensong Exp $
+ * 	$Id: ip_vs_app.c,v 1.4 2000/09/06 08:36:36 wensong Exp $
  *
  * Author:	Juan Jose Ciarlante, <jjciarla@raiz.uncu.edu.ar>
  *
@@ -60,10 +60,10 @@ EXPORT_SYMBOL(unregister_ip_vs_app);
 /*
  * 	will hold ipvs app. hashed list heads
  */
-struct list_head ip_vs_app_base[IP_VS_APP_TAB_SIZE];
+static struct list_head ip_vs_app_base[IP_VS_APP_TAB_SIZE];
 
 /* lock for ip_vs_app table */
-rwlock_t __ip_vs_app_lock = RW_LOCK_UNLOCKED;
+static rwlock_t __ip_vs_app_lock = RW_LOCK_UNLOCKED;
 
 
 /*
@@ -127,7 +127,7 @@ int unregister_ip_vs_app(struct ip_vs_app *vapp)
 /*
  *	get ip_vs_app object by its proto and port (net byte order).
  */
-struct ip_vs_app * ip_vs_app_get(unsigned short proto, __u16 port)
+static struct ip_vs_app * ip_vs_app_get(unsigned short proto, __u16 port)
 {
         struct list_head *e;
         struct ip_vs_app *vapp;
@@ -411,7 +411,8 @@ int ip_vs_app_pkt_in(struct ip_vs_conn *cp, struct sk_buff **skb_p)
 /*
  *	/proc/net/ip_vs_app entry function
  */
-int ip_vs_app_getinfo(char *buffer, char **start, off_t offset, int length)
+static int ip_vs_app_getinfo(char *buffer, char **start, off_t offset,
+			     int length)
 {
         off_t pos=0, begin;
         int len=0;
@@ -545,7 +546,7 @@ struct sk_buff *ip_vs_skb_replace(struct sk_buff *skb, int pri, char *o_buf,
         struct sk_buff *n_skb;
         unsigned skb_len;
 
-	EnterFunction(1);
+	EnterFunction(4);
 
         diff = n_len - o_len;
         n_skb = skb_replace(skb, pri, o_buf, o_len, n_buf, n_len);
@@ -560,12 +561,12 @@ struct sk_buff *ip_vs_skb_replace(struct sk_buff *skb, int pri, char *o_buf,
                  * 	update ip header
                  */
                 iph = n_skb->nh.iph;
+                iph->tot_len = htons(skb_len + diff);
                 iph->check = 0;
                 iph->check = ip_fast_csum((unsigned char *)iph, iph->ihl);
-                iph->tot_len = htons(skb_len + diff);
         }
         
-        LeaveFunction(1);
+        LeaveFunction(4);
         return n_skb;
 }
 
