@@ -1,7 +1,7 @@
 /*
  * IP_VS        ftp application module
  *
- * Version:	$Id: ip_vs_ftp.c,v 1.1 2000/07/30 04:10:05 wensong Exp $
+ * Version:	$Id: ip_vs_ftp.c,v 1.2 2000/09/06 08:36:36 wensong Exp $
  *
  * Authors:	Wensong Zhang <wensong@linuxvirtualserver.org>
  *		
@@ -83,9 +83,10 @@ ip_vs_ftp_done_conn(struct ip_vs_app *mapp, struct ip_vs_conn *cp)
  * with the "pattern" and terminated with the "term" character.
  * <addr,port> is in network order.
  */
-int ip_vs_ftp_get_addrport(char *data, char *data_limit,
-                           const char *pattern, size_t plen, char term,
-                           __u32 *addr, __u16 *port, char **start, char **end)
+static int ip_vs_ftp_get_addrport(char *data, char *data_limit,
+				  const char *pattern, size_t plen, char term,
+				  __u32 *addr, __u16 *port,
+				  char **start, char **end)
 {
 	unsigned char p1,p2,p3,p4,p5,p6;
 
@@ -135,8 +136,8 @@ int ip_vs_ftp_get_addrport(char *data, char *data_limit,
  *   "227 Entering Passive Mode (xxx,xxx,xxx,xxx,ppp,ppp)".
  * xxx,xxx,xxx,xxx is the server address, ppp,ppp is the server port number.
  */
-int ip_vs_ftp_out(struct ip_vs_app *mapp,
-                  struct ip_vs_conn *cp, struct sk_buff **skb_p)
+static int ip_vs_ftp_out(struct ip_vs_app *mapp,
+			 struct ip_vs_conn *cp, struct sk_buff **skb_p)
 {
         struct sk_buff *skb;
 	struct iphdr *iph;
@@ -236,8 +237,8 @@ int ip_vs_ftp_out(struct ip_vs_app *mapp,
  * port, so that the active ftp data connection from the server can reach
  * the client.
  */
-int ip_vs_ftp_in(struct ip_vs_app *mapp,
-                 struct ip_vs_conn *cp, struct sk_buff **skb_p)
+static int ip_vs_ftp_in(struct ip_vs_app *mapp,
+			struct ip_vs_conn *cp, struct sk_buff **skb_p)
 {
 	struct sk_buff *skb;
 	struct iphdr *iph;
@@ -319,7 +320,7 @@ int ip_vs_ftp_in(struct ip_vs_app *mapp,
 }
 
 
-struct ip_vs_app ip_vs_ftp = {
+static struct ip_vs_app ip_vs_ftp = {
         {0},			/* n_list */
 	"ftp",			/* name */
         0,                      /* type */
@@ -334,7 +335,7 @@ struct ip_vs_app ip_vs_ftp = {
 /*
  * 	ip_vs_ftp initialization
  */
-int __init ip_vs_ftp_init(void)
+static int __init ip_vs_ftp_init(void)
 {
 	int i, j;
 
@@ -367,7 +368,7 @@ int __init ip_vs_ftp_init(void)
 /*
  * 	ip_vs_ftp finish.
  */
-void __exit ip_vs_ftp_exit(void)
+static void __exit ip_vs_ftp_exit(void)
 {
 	int i, j, k;
 
