@@ -1,7 +1,7 @@
 /*
  * IPVS:        Round-Robin Scheduling module
  *
- * Version:     $Id: ip_vs_rr.c,v 1.3 2000/09/06 08:36:36 wensong Exp $
+ * Version:     $Id: ip_vs_rr.c,v 1.4 2000/11/26 04:35:39 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -55,7 +55,8 @@ static int ip_vs_rr_update_svc(struct ip_vs_service *svc)
 /*
  * Round-Robin Scheduling
  */
-static struct ip_vs_dest* ip_vs_rr_schedule(struct ip_vs_service *svc)
+static struct ip_vs_dest *
+ip_vs_rr_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 {
 	register struct list_head *p, *q;
         struct ip_vs_dest *dest;
