@@ -1,7 +1,7 @@
 /*
  * IPVS:        Weighted Least-Connection Scheduling module
  *
- * Version:     $Id: ip_vs_wlc.c,v 1.4 2000/09/06 08:36:36 wensong Exp $
+ * Version:     $Id: ip_vs_wlc.c,v 1.5 2000/11/26 04:35:39 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -57,7 +57,7 @@ ip_vs_wlc_update_svc(struct ip_vs_service *svc)
  *    Weighted Least Connection scheduling
  */
 static struct ip_vs_dest *
-ip_vs_wlc_schedule(struct ip_vs_service *svc)
+ip_vs_wlc_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 {
 	register struct list_head *l, *e;
 	struct ip_vs_dest *dest, *least;
@@ -101,14 +101,12 @@ ip_vs_wlc_schedule(struct ip_vs_service *svc)
 	 *    Find the destination with the least load.
 	 */
   nextstage:
-	for (e=e->next; e!=l; e=e->next)
-	{
+	for (e=e->next; e!=l; e=e->next) {
 		dest = list_entry(e, struct ip_vs_dest, n_list);
 		doh = atomic_read(&dest->activeconns) * 50
 			+ atomic_read(&dest->inactconns);
 		if (loh * atomic_read(&dest->weight) >
-                    doh * atomic_read(&least->weight))
-		{
+                    doh * atomic_read(&least->weight)) {
 			least = dest;
 			loh = doh;
 		}
